@@ -26,15 +26,15 @@
 DlgEngineEditing::DlgEngineEditing(QWidget *parent)
     : QDialog(parent)
 {
-    QWidget *mainWidget = new QWidget(this);
+    auto *mainWidget = new QWidget(this);
     ui.setupUi(mainWidget);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
+    auto *mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
     mainLayout->addWidget(mainWidget);
 
     setWindowTitle(i18n("Insert Engine"));
     setModal(true);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
     okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -91,9 +91,9 @@ void DlgSettingsWidget::slotNewEngine()
     if(dialog.exec()) {
         addSearchEngineItem(dialog.engineName(), dialog.engineUrl());
 #if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-        emit changed();
+        Q_EMIT changed();
 #else
-        emit markAsChanged();
+        Q_EMIT markAsChanged();
 #endif
     }
 }
@@ -105,9 +105,9 @@ void DlgSettingsWidget::slotRemoveEngine()
     foreach(QTreeWidgetItem * selectedItem, selectedItems)
         delete(selectedItem);
 #if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-        emit changed();
+        Q_EMIT changed();
 #else
-        emit markAsChanged();
+        Q_EMIT markAsChanged();
 #endif
 }
 
@@ -120,9 +120,9 @@ void DlgSettingsWidget::addSearchEngineItem(const QString &name, const QString &
 {
     ui.enginesTreeWidget->addTopLevelItem(new QTreeWidgetItem(QStringList() << name << url));
 #if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-        emit changed();
+        Q_EMIT changed();
 #else
-        emit markAsChanged();
+        Q_EMIT markAsChanged();
 #endif
 }
 
